MatterWave

Struct MatterWave 

pub struct MatterWave {
    pub momentum: f64,
}
A lightweight matter-wave wrapper stored by momentum magnitude.

Fields

momentum: f64

Momentum magnitude in kilogram meters per second.

Implementations

Source

impl MatterWave

pub fn from_momentum(momentum: f64) -> Option<Self>

Creates a matter wave from a positive finite momentum magnitude.

pub fn from_mass_velocity(mass: f64, velocity: f64) -> Option<Self>

Creates a matter wave from mass and velocity magnitude.

Examples
use use_quantum::{MatterWave, PLANCK_CONSTANT};

let wave = MatterWave::from_mass_velocity(2.0, 3.0).ok_or("expected valid inputs")?;

assert!((wave.wavelength().ok_or("expected wavelength")? - (PLANCK_CONSTANT / 6.0)).abs() < 1.0e-12);
Examples found in repository?
examples/basic_usage.rs (line 14)
11fn main() -> Result<(), &'static str> {
12    let photon = Photon::from_wavelength(500.0e-9).ok_or("expected valid photon wavelength")?;
13    let matter_wave =
14        MatterWave::from_mass_velocity(2.0, 3.0).ok_or("expected valid matter wave")?;
15    let quantum_numbers =
16        QuantumNumbers::new(2, 1, 0, 1).ok_or("expected valid quantum numbers")?;
17
18    assert!(photon.energy_ev().ok_or("expected photon energy in eV")? > 0.0);
19    assert!(
20        matter_wave
21            .wavelength()
22            .ok_or("expected matter wavelength")?
23            > 0.0
24    );
25    assert!(approx_eq(quantum_numbers.spin_projection(), 0.5));
26    assert!(approx_eq(
27        hydrogen_energy_level_ev(1).ok_or("expected hydrogen energy level")?,
28        -RYDBERG_ENERGY_EV,
29    ));
30    assert!(approx_eq(
31        minimum_position_uncertainty(REDUCED_PLANCK_CONSTANT)
32            .ok_or("expected minimum uncertainty")?,
33        0.5,
34    ));
35
36    Ok(())
37}
pub fn wavelength(&self) -> Option<f64>

Returns the de Broglie wavelength in meters.

Examples found in repository?
examples/basic_usage.rs (line 21)
11fn main() -> Result<(), &'static str> {
12    let photon = Photon::from_wavelength(500.0e-9).ok_or("expected valid photon wavelength")?;
13    let matter_wave =
14        MatterWave::from_mass_velocity(2.0, 3.0).ok_or("expected valid matter wave")?;
15    let quantum_numbers =
16        QuantumNumbers::new(2, 1, 0, 1).ok_or("expected valid quantum numbers")?;
17
18    assert!(photon.energy_ev().ok_or("expected photon energy in eV")? > 0.0);
19    assert!(
20        matter_wave
21            .wavelength()
22            .ok_or("expected matter wavelength")?
23            > 0.0
24    );
25    assert!(approx_eq(quantum_numbers.spin_projection(), 0.5));
26    assert!(approx_eq(
27        hydrogen_energy_level_ev(1).ok_or("expected hydrogen energy level")?,
28        -RYDBERG_ENERGY_EV,
29    ));
30    assert!(approx_eq(
31        minimum_position_uncertainty(REDUCED_PLANCK_CONSTANT)
32            .ok_or("expected minimum uncertainty")?,
33        0.5,
34    ));
35
36    Ok(())
37}